@@ -56,6 +56,7 @@ class QuickbooksOnlineSDK:
         self.purchases = Purchases()
         self.journal_entries = JournalEntries()
         self.attachments = Attachments()
+        self.bill_payments = BillPayments()
 
         self.update_server_url()
         self.update_access_token()
@@ -79,6 +80,7 @@ class QuickbooksOnlineSDK:
         self.journal_entries.set_server_url(base_url)
         self.customers.set_server_url(base_url)
         self.attachments.set_server_url(base_url)
+        self.bill_payments.set_server_url(base_url)
 
     def update_access_token(self):
         """
@@ -100,6 +102,7 @@ class QuickbooksOnlineSDK:
         self.journal_entries.change_access_token(access_token)
         self.customers.change_access_token(access_token)
         self.attachments.change_access_token(access_token)
+        self.bill_payments.change_access_token(access_token)
 
     def __get_access_token(self):
         """Get the access token using a HTTP post.
